# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from __future__ import annotations

from cadwyn import VersionChange, endpoint, schema

from airflow.api_fastapi.execution_api.routes.xcoms import GetXcomFilterParams


class RemoveTIRuntimeChecksEndpoint(VersionChange):
    """Remove the runtime-check endpoint as it does nothing anymore."""

    description = __doc__
    instructions_to_migrate_to_previous_version = (
        endpoint("/task-instances/{task_instance_id}/runtime-checks", ["POST"]).existed,
    )


class AddIncludePriorDatesParam(VersionChange):
    """Add the `include_prior_dates` query parameter to the GET XCom API."""

    description = __doc__

    instructions_to_migrate_to_previous_version = (
        schema(GetXcomFilterParams).field("include_prior_dates").didnt_exist,
    )
